/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.bc.sql;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

/**
 * @author Adrien Louis - EBM WebSourcing
 */
public class DriverResolver {

    protected static Properties _staticMapping = new Properties();

    static {
        InputStream propertyfile = DriverResolver.class.getClassLoader().getResourceAsStream(
                "jdbcDriverMapping.properties");

        if (propertyfile != null) {
            try {
                _staticMapping.load(propertyfile);
            } catch (IOException e) {
                //
            }
        }
    }

    /**
     * Resolve JDBC Driver className with the connection URI. <li>mysql</li> <li>
     * oracle</li> <li>hsql</li> <li>sqlserver</li> <li>derby</li> <li>
     * postgresql</li> <li>db2</li>
     * 
     * @param jdbcConnectionURI
     * @return driver className
     */
    public static String resolveDriverClassname(String jdbcConnectionURI) {
        String className = null;
        for (Object key : _staticMapping.keySet()) {
            if (jdbcConnectionURI.contains((String) key)) {
                className = _staticMapping.getProperty((String) key);
            }
        }
        return className;
    }
}
